/**
 * Form Validation
 * https://github.com/jms8142/form-validator-plugin
 *
 * see demo.html for examples
 * 
 * 
 * Usage:
 * 
 * $(formSelector).validateForm(opts);
 *
 * To run without submitting form:
 *
 * $(formSelector).validateForm('runValidation')
 *
 * reset form:
 *  $(formSelector).validateForm('resetForm')
 * 
 * @author John Skrzypek
 * @version 1.0
 * @date 09/19/2012	
 */




 /**
 * The main isEmailField for the formValidator collection.  
 * 
 * 
 * @author John Skrzypek
 * @version 1.0
 * @date 12/19/2011	
 */


 (function($){
	$.fn.isEmailField = function(options){
		return this.each(function(){
			var el = $(this);
			var email_pattern = /.+@.+\..+/;
			var emailInfo = $("#email_info");
			
			function checkEmail(){
				emailAddress = el.val();				
				if (emailAddress.match(email_pattern)) {
					el.trigger("is-valid");
				} else {
					el.trigger("is-invalid","Should look like an email address");
				}
			}
			
			el.isNameField({
				required : (options.required !== undefined) ? options.required : false,
				requiredMessage : (options.requiredMessage !== undefined) ? options.requiredMessage : "",
				validateWith: function(I){
					if (options.required && !I.match(email_pattern)) {
						return "Should look like an email address";
					} else {
						return true;
					}
				},
				allowInput: /[^\s]/,
				message : (options !== undefined) ? (options.message || '123') : '456'
			});
			
			el.blur(function(){
				if (el.val() == "") {
					el.trigger("show-info");
					el.parent("div").find(".alert-box.info").hide();
					el.removeClass("with-box")
				}
				else {
					checkEmail();
				}
			});
			
		});
	}
})(jQuery);


(function($){
	$.fn.isCheckBoxField = function(options){
		return this.each(function(){
			var el = $(this);
		});
		
	}

})(jQuery);




/**
 * The main isNameField for the formValidator collection.  
 * 
 * 
 * @author John Skrzypek
 * @version 1.0
 * @date 12/19/2011	
 */
 (function($){
	
	var methods = {
		init : function(options){

			var settings = $.extend({
								requiredMessage : "Field is required"
								},options);
			
				return this.each(function(){
				
				var el = $(this),
				data = el.data('isNameField');

				if(!data){
					$(this).data('isNameField',settings);
				}

				//Set up elements
				var extraElements = [
										{ classes : "alert-box info", text : settings.message},
										{ classes : "alert-box good", text : "OK"},
										{ classes : "alert-box error", text : ""}
									]
				
				for(_index in extraElements){
						var div = $('<div>');
						div.html(extraElements[_index].text);
						div.addClass(extraElements[_index].classes);
						el.after(div);
				}
				

				var oneUp = el.parent("div");
				var alertBox = oneUp.find(".alert-box");
				var alertBoxInfo = oneUp.find(".alert-box.info");
				var alertBoxGood = oneUp.find(".alert-box.good");
				var alertBoxError= oneUp.find(".alert-box.error");
				var activeAlert = alertBoxInfo;
				var currentVal = el.val();
				var updated = currentVal != "";
				var infobox = "";
				var _allowInput = settings.allowInput;
				var errorsExist = el.parent("div.fieldWithErrors").length>0;
				var valFunc = settings.validateWith;
				var done = false;
				
				
				function showInfo(){

					if(!(el.val().length===0 && settings.required===false && activeAlert.hasClass('good'))) { //don't show OK if this is not required
						activeAlert.show();
					}

					el.addClass("done");
				}
				
				function hideInfo(){
					if (!done) {
						activeAlert.hide();
						el.removeClass("done");
					}
					
				}
				
				function updateMes(box){
					activeAlert.hide();
					activeAlert = box;
					showInfo();
				}
				
				function checkVal(a){ //if a validateWith function exists, return, else return true
					return valFunc ? valFunc(a) : true;
				}
				
				function validEntry(){
					if(settings.required){
						done = true;
						
						activeAlert.hide();
						activeAlert = alertBoxGood;
						
						if(el.hasClass("errorDetected" )) { el.removeClass("errorDetected") }

						showInfo();
					}
				}
				
				function isInvalid(){
					done = true;
					el.addClass("errorDetected")
					updateMes(alertBoxError);
				}
				
				function fieldUpdated(){ //check if field has been updated
					var newVal = el.val();
					updated = (newVal != currentVal);
		
					if(updated){
						errorsExist=false
					}	
					currentVal = newVal;
					return updated;
				}
				
				function checkValue(){
					var a = true;

					if(settings.required){
						a = (!isBlank(el.val()) && checkVal(el.val()));
					}

					if(a===true){
						el.trigger("is-valid")
					} else {
						if(typeof (a)=="boolean"){
							a = settings.requiredMessage;	
						}

						el.trigger("is-invalid",a) //trigger is-invalid function and update alert error text
					}
				}

				function isBlank(str) { 
					return str.replace(/\s+/g,"").length==0  //empty space and return length
				} 
				
				el.focus(showInfo);
				
				el.blur(function(){
					if(fieldUpdated()){
						if(errorsExist){
							el.trigger("is-invalid")
						} else {
							
							if(updated){
								checkValue();
							}
							
						}
					}
					hideInfo();
				});
				
				el.bind("is-invalid",isInvalid);
				el.bind("is-valid",validEntry);
				el.bind("check-value",checkValue);
				el.bind("is-invalid",function(b,mes){
						if(mes){
							alertBoxError.html(mes)
						}
					});
				
				
				if(_allowInput){
					el.keypress(function(k){
						var keyp = k.which;
						var chrCode = String.fromCharCode(keyp);
						return !!(keyp==0||keyp==8||keyp==9||keyp==13||chrCode.match(_allowInput))
					});
				}
				
				alertBox.hide();
				
			});
			
		},
		setOption : function(option,val){
			return this.each(function(){
				eval("$(this).data('isNameField')." + option + "=" + val); //there must be a better way				
			});
		}
	}
	
	
	
	$.fn.isNameField = function(method){

		if (methods[method]){ //if this is a predefined method, run it
			return methods[method].apply(this,Array.prototype.slice.call(arguments,1));
		} else if ( typeof method === 'object' || ! method) { //if this contains data as an object, pass the element and object to the init() method
			return methods.init.apply(this,arguments);
		} else {
			$.error('Method ' + method + ' does not exists on jQuery.isNameField'); //no method found here
		}
		
	}
	

})(jQuery);




 
(function($){

	var methods = {
		init : function(options){
			return this.each(function(){
				var frm = $(this);

				//apply formatting
				if(!$(frm).hasClass('formValidator'))
					$(frm).addClass('formValidator')
				
				$(frm).submit(function(){
					var check = methods.checkForm(frm);

					if(options && options.onSuccess && check)  {
	         			if(typeof options.onSuccess == 'function') {
	         				check = options.onSuccess();
	         			}
	         		}
	         		
					return check;
				});
				
			
			});
		},
		runValidation : function(){
			return methods.checkForm($(this));
		},
		checkForm : function(frm){
			var good = true;
		
			$(frm).find(':input').each(function(){
				if($(this).parent().children('div.alert-box').length>0){ //look for fields to validate
					$(this).trigger('check-value'); //check field again on submit
					if($(this).hasClass('errorDetected')){
						good = false;
					}
				}
			});
			
		        //shake the box
		        if(!good && (jQuery.ui)) {
		            $(frm).find(':submit').effect('shake',{times:2},150);
		        }

			return good;
		},
		resetForm : function(){
			var frm = $(this);
			$(this).find(':input').each(function(){
				if($(this).hasClass("errorDetected" )) $(this).removeClass("errorDetected");
				if($(this).hasClass("done" )) $(this).removeClass("done");
				$(frm).find('.alert-box').hide();
			});
			
		}

	} //methods

	$.fn.validateForm = function(method){
		//var settings = $.extend(options);
		if (methods[method]){ //if this is a predefined method, run it
			return methods[method].apply(this,Array.prototype.slice.call(arguments,1));
		} else if ( typeof method === 'object' || ! method) { //if this contains data as an object, pass the element and object to the init() method
			return methods.init.apply(this,arguments);
		} else {
			$.error('Method ' + method + ' does not exists on jQuery.validateForm'); //no method found here
		}


	}

	
})(jQuery);